@@ -61,10 +61,10 @@ class TestTokenDeploy:
             self.start_time = int(r['timestamp'])
 
 
-    def deploy(self, rpc, deployer_address, interface, supply_cap=0):
+    def publish(self, rpc, publisher_address, interface, supply_cap=0):
         tx_hash = None
         o = None
-        (tx_hash, o) = interface.constructor(deployer_address, self.settings)
+        (tx_hash, o) = interface.constructor(publisher_address, self.settings)
 
         r = rpc.do(o)
         o = receipt(tx_hash)
@@ -89,7 +89,7 @@ class TestDemurrage(EthTesterCase):
             period = getattr(self, 'period')
         except AttributeError as e:
             pass
-        self.deployer = TestTokenDeploy(self.rpc, period=period, sink_address=self.accounts[9])
+        self.publisher = TestTokenDeploy(self.rpc, period=period, sink_address=self.accounts[9])
         self.default_supply = 0
         self.default_supply_cap = 0
         self.start_block = None
@@ -97,13 +97,13 @@ class TestDemurrage(EthTesterCase):
         self.start_time = None
 
 
-    def deploy(self, interface):
-        self.address = self.deployer.deploy(self.rpc, self.accounts[0], interface, supply_cap=self.default_supply_cap)
-        self.start_block = self.deployer.start_block
-        self.start_time = self.deployer.start_time
-        self.tax_level = self.deployer.tax_level
-        self.period_seconds = self.deployer.period_seconds
-        self.sink_address = self.deployer.sink_address
+    def publish(self, interface):
+        self.address = self.publisher.publish(self.rpc, self.accounts[0], interface, supply_cap=self.default_supply_cap)
+        self.start_block = self.publisher.start_block
+        self.start_time = self.publisher.start_time
+        self.tax_level = self.publisher.tax_level
+        self.period_seconds = self.publisher.period_seconds
+        self.sink_address = self.publisher.sink_address
 
         logg.debug('contract address {} start block {} start time {}'.format(self.address, self.start_block, self.start_time))
 
@@ -119,6 +119,13 @@ class TestDemurrage(EthTesterCase):
         raise AssertionError('{} not within lower {} and higher {}'.format(v, lower_target, higher_target))
 
 
+    def assert_within_greater(self, v, target, tolerance_ppm):
+        greater_target = target + (target * (tolerance_ppm / 1000000))
+        self.assertLessEqual(v, greater_target)
+        self.assertGreaterEqual(v, target)
+        logg.debug('asserted within greater {} >= {} >= {}'.format(greater_target, v, target))
+
+
     def assert_within_lower(self, v, target, tolerance_ppm):
         lower_target = target - (target * (tolerance_ppm / 1000000))
         self.assertGreaterEqual(v, lower_target)
@@ -144,7 +151,7 @@ class TestDemurrageDefault(TestDemurrage):
         nonce_oracle = RPCNonceOracle(self.accounts[0], self.rpc)
         c = DemurrageToken(self.chain_spec, signer=self.signer, nonce_oracle=nonce_oracle)
 
-        self.deploy(c)
+        self.publish(c)
 
         self.default_supply = 10**12
         self.default_supply_cap = self.default_supply
